@@ -1,6 +1,6 @@
 package Test::Excel;
 
-$Test::Excel::VERSION   = '1.52';
+$Test::Excel::VERSION   = '1.53';
 $Test::Excel::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Test::Excel - Interface to test and compare Excel files (.xls/.xlsx).
 
 =head1 VERSION
 
-Version 1.52
+Version 1.53
 
 =cut
 
@@ -39,7 +39,7 @@ my $TESTER               = Test::Builder->new;
 
 This  module is meant to be used for testing  custom  generated  Excel  files, it
 provides interfaces to compare_excel two Excel files if they are I<visually> same.
-It now supports Excel file with extension C<.xls> and C<.xlsx>.
+It now supports Excel files with the extensions C<.xls> or C<.xlsx>.
 
 =head1 SYNOPSIS
 
@@ -72,8 +72,8 @@ Using as standalone as below:
 =head2 cmp_excel($got, $exp, \%rule, $message)
 
 This function will tell you whether the two Excel files are "visually" different,
-ignoring differences  in  embedded  fonts / images and metadata.Both C<$got> and
-C<$exp>  can be either instance of L<Spreadsheet::Read> / file path (which is in
+ignoring differences in embedded fonts / images and metadata. Both C<$got> and
+C<$exp> can be either instance of L<Spreadsheet::Read> / file path (which is in
 turn passed to the L<Spreadsheet::Read> constructor).
 This one is for use in TEST MODE.
 
@@ -123,10 +123,10 @@ sub cmp_excel_not_ok {
 
 =head2 compare_excel($got, $exp, \%rule)
 
-Same as C<cmp_excel_ok()> but ideal for non TEST MODE.
+Same as C<cmp_excel_ok()> but ideal for non-TEST MODE.
 This function will tell you whether the two Excel files are "visually" different,
-ignoring differences  in  embedded  fonts / images and metadata.Both C<$got> and
-C<$exp>  can be either instance of L<Spreadsheet::Read> / file path (which is in
+ignoring differences in embedded fonts / images and metadata. Both C<$got> and
+C<$exp> can be either instance of L<Spreadsheet::Read> / file path (which is in
 turn passed to the L<Spreadsheet::Read> constructor).
 
     use strict; use warnings;
@@ -397,7 +397,7 @@ sub compare_excel {
 
 =head1 RULE
 
-The paramter C<rule> can be used optionally to apply exception when comparing the
+The parameter C<rule> can be used optionally to apply exception when comparing the
 contents. This should be passed in as has ref and may contain keys from the table
 below.
 
@@ -416,8 +416,8 @@ below.
 
 =head1 SPECIFICATION FILE
 
-Spec  file containing rules used should be in the format mentioned below. Key and
-values are space seperated.
+A spec file containing rules used should be in the format mentioned below. Keys
+and values are space-separated.
 
     sheet       Sheet1
     range       A3:B14
@@ -426,10 +426,11 @@ values are space seperated.
     range       A1:B2
     ignorerange B3:B8
 
-As in C<v1.51> or above, we now support the use of C<regex> in the specification
-file.
+As in C<v1.51> or above, we now support the use of C<regex> in the
+specification file.
 
-The following specification forces regex comparison in all sheets in range C<B2:B4>.
+The following specification forces regex comparison in all sheets in
+range C<B2:B4>.
 
     sheet ALL
     range B2:B4
@@ -440,27 +441,28 @@ The following specification forces regex comparison in all sheets.
     sheet ALL
     regex 2022\-\d\d\-\d\d
 
-The following specification forces regex comparison in the sheet named C<Demo>
-in range C<B2:B4>.
+The following specification forces regex comparison in the sheet
+named C<Demo> in range C<B2:B4>.
 
     sheet Demo
     range B2:B4
     regex 2022\-\d\d\-\d\d
 
-=head1 What is "Visually" Similar?
+=head1 What Is "Visually" Similar?
 
-This module uses  the L<Spreadsheet::Read> module  to parse the Excel files, then
-compares the parsed  data structure for differences.We ignore certain  components
-of the Excel file, such as embedded fonts,  images,  forms and  annotations,  and
-focus  entirely  on  the layout of each Excel page instead.  Future versions will
-likely support font and image comparisons.
+This module uses the L<Spreadsheet::Read> module to parse the Excel
+files and then compares the parsed data structure for differences. It
+ignores certain components of the Excel file, such as embedded fonts,
+images, forms and annotations, and focuses entirely on the layout of
+each Excel page instead. Future versions may support font and image
+comparisons as well.
 
 =head1 How to find out what failed the comparison?
 
-By turning the environment variable DEBUG ON would spit out PASS/FAIL comparison.
-For example:
+Setting the environment variable DEBUG to a non-zero, non-empty value
+will output the PASS/FAIL comparison. For example:
 
-    $/> $DEBUG=1 perl your-test-script.pl
+    $> $DEBUG=1 perl your-test-script.pl
 
 =cut
 
@@ -473,7 +475,8 @@ sub _column_row {
 
     return unless defined $cell;
 
-    die("ERROR: Invalid cell address [$cell].\n") unless ($cell =~ /([A-Za-z]+)(\d+)/);
+    die "ERROR: Invalid cell address [$cell].\n"
+        unless ($cell =~ /([A-Za-z]+)(\d+)/);
 
     return ($1, $2);
 }
@@ -484,9 +487,9 @@ sub _letter_to_number {
     return col2int($letter);
 }
 
-# --------------------------------------------------------------------------
+# -------------------------------------------------------------------
 # col2int (for Spreadsheet::ParseExcel::Utility)
-# --------------------------------------------------------------------------
+# -------------------------------------------------------------------
 sub col2int {
     my $result = 0;
     my $str    = shift;
@@ -512,9 +515,9 @@ sub _number_to_letter {
     return int2col($number);
 }
 
-# --------------------------------------------------------------------------
+# -------------------------------------------------------------------
 # int2col (for Spreadsheet::ParseExcel::Utility)
-# --------------------------------------------------------------------------
+# -------------------------------------------------------------------
 sub int2col {
     my $out = "";
     my $val = shift;
@@ -534,7 +537,7 @@ sub _cells_within_range {
 
     my $cells = [];
     foreach my $_range (split /\,/,$range) {
-        die("ERROR: Invalid range [$_range].\n")
+        die "ERROR: Invalid range [$_range].\n"
             unless ($_range =~ /(\w+\d+):(\w+\d+)/);
 
         my $from = $1;
@@ -560,12 +563,14 @@ sub _parse {
 
     return unless defined $spec;
 
-    die("ERROR: Unable to locate spec file [$spec][$!].\n") unless (-f $spec);
+    die "ERROR: Unable to locate spec file [$spec][$!].\n"
+        unless (-f $spec);
 
     my $data   = undef;
     my $sheet  = undef;
     my $regex  = undef;
-    my $handle = IO::File->new($spec) || die("ERROR: Couldn't open file [$spec][$!].\n");
+    my $handle = IO::File->new($spec)
+        || die "ERROR: Couldn't open file [$spec][$!].\n";
 
     while (my $row = <$handle>) {
         chomp($row);
@@ -596,7 +601,7 @@ sub _parse {
             }
         }
         else {
-            die("ERROR: Invalid format data [$row] found in spec file.\n");
+            die "ERROR: Invalid format data [$row] found in spec file.\n";
         }
     }
 
@@ -643,24 +648,26 @@ sub _validate_rule {
 
     return unless defined $rule;
 
-    die("ERROR: Invalid RULE definitions. It has to be reference to a HASH.\n")
+    die "ERROR: Invalid RULE definitions. It has to be reference to a HASH.\n"
         unless (ref($rule) eq 'HASH');
 
     my ($keys, $valid);
     $keys = scalar(keys(%{$rule}));
     return if (($keys == 1) && exists $rule->{message});
 
-    die("ERROR: Rule has more than 8 keys defined.\n")
+    die "ERROR: Rule has more than 8 keys defined.\n"
         if $keys > 8;
 
-    $valid = {'message'         => 1,
-              'sheet'           => 2,
-              'spec'            => 3,
-              'tolerance'       => 4,
-              'sheet_tolerance' => 5,
-              'error_limit'     => 6,
-              'swap_check'      => 7,
-              'test'            => 8,};
+    $valid = {
+        'message'         => 1,
+        'sheet'           => 2,
+        'spec'            => 3,
+        'tolerance'       => 4,
+        'sheet_tolerance' => 5,
+        'error_limit'     => 6,
+        'swap_check'      => 7,
+        'test'            => 8,
+    };
 
     foreach my $key (keys %{$rule}) {
         die "ERROR: Invalid key '$key' found in the rule definitions.\n"
@@ -697,24 +704,24 @@ sub _validate_rule {
 
 =head1 NOTES
 
-It should be clearly noted that this module does not claim to provide  fool-proof
-comparison of generated Excels. In fact there are still a number of ways in which
-I want to expand the existing comparison functionality. This module  is no longer
- actively being developed as I moved to another company.This work was part of one
-of my project. Having said, I would be more than happy to add new features if its
-requested. Any suggestions / ideas most welcome.
+It should be clearly noted that this module does not claim to provide fool-proof
+comparison of generated Excel files. In fact there are still a number of ways in
+which I want to expand the existing comparison functionality. This module is no
+longer actively being developed as I moved to another company. This work was part
+of one of my projects. Having said that, I would be more than happy to add new
+features if requested. Any suggestions / ideas most welcome.
 
 =head1 CAVEATS
 
-Testing of large Excels can take a long time, this is because, well, we are doing
-a lot of computation. In fact, this   module   test  suite includes tests against
-several  large  Excels,  however I am not including those in this distibution for
+Testing large Excel files can take a long time. This is because, well, it is doing
+a lot of computation. In fact, the test suite for this module includes tests against
+several large Excel files; however, I am not including those in this distibution for
 obvious reasons.
 
 =head1 BUGS
 
-None that I am aware of.Of course, if you find a bug, let me know, and I would do
-my best  to fix it.  This is still a very early version, so it is always possible
+None that I am aware of. Of course, if you find a bug, let me know, and I would do
+my best to fix it. This is still a very early version, so it is always possible
 that I have just "gotten it wrong" in some places.
 
 =head1 SEE ALSO
@@ -741,13 +748,23 @@ that I have just "gotten it wrong" in some places.
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item * Julien Fiegehenn
+
+=item * Ed Sabol
+
+=back
+
 =head1 REPOSITORY
 
 L<https://github.com/manwar/Test-Excel>
 
 =head1 BUGS
 
-Please  report  any bugs or feature requests to C<bug-test-excel at rt.cpan.org>,
+Please report any bugs or feature requests to C<bug-test-excel at rt.cpan.org>,
 or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Excel>.
 I will be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
@@ -762,9 +779,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Excel>
+L<https://github.com/manwar/Test-Excel/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -774,15 +791,15 @@ L<http://annocpan.org/dist/Test-Excel>
 
 L<http://cpanratings.perl.org/d/Test-Excel>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Test-Excel/>
+L<https://metacpan.org/dist/Test-Excel/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2010 - 2016 Mohammad S Anwar.
+Copyright (C) 2010 - 2022 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it  and/or modify it under
 the  terms  of the the Artistic License (2.0). You may  obtain a copy of the full
